@@ -10,26 +10,23 @@ import urllib
 import urllib2
 
 WELCOME_BANNER = """
- ____      ____             __                             
-|_  _|    |_  _|           [  |                            
-  \ \  /\  / /.---.  .---.  | |  .--.   _ .--..--.  .---.  
-   \ \/  \/ // /__\\/ /'`\] | |/ .'`\ \[ `.-. .-. |/ /__\\ 
-    \  /\  / | \__.,| \__.  | || \__. | | | | | | || \__., 
-     \/  \/   '.__.''.___.'[___]'.__.' [___||__||__]'.__.' 
-                                                           
-                     _________                             
-                    |  _   _  |                            
-                    |_/ | | \_|.--.                        
-                        | |  / .'`\ \                      
-                       _| |_ | \__. |                      
-                      |_____| '.__.'                       
-                                                           
-            ________   _                   _               
-           |  __   _| (_)                 | |              
-           |_/  / /   __   _ .--.   .---. | |              
-              .'.' _ [  | [ `.-. | / /'`\]| |              
-            _/ /__/ | | |  | | | | | \__. |_|              
-           |________|[___][___||__]'.___.'(_)              
+ ____      ____      __                                     
+|_  _|    |_  _|    [  |                                    
+  \ \  /\  / /.---.  | |  .---.   .--.   _ .--..--.  .---.  
+   \ \/  \/ // /_\ \ | | / /'`\]/ .'`\ \[ `.-. .-. |/ /_\ \ 
+    \  /\  / | \__., | | | \__. | \__. | | | | | | || \__., 
+     \/  \/   '.__.'[___]'.___.' '.__.' [___||__||__]'.__.' 
+                       _________                            
+                      |  _   _  |                           
+                      |_/ | | \_|.--.                       
+                          | |  / .'`\ \                     
+                         _| |_ | \__. |                     
+              ________  |_____| '.__.'       _              
+             |  __   _| (_)                 | |             
+             |_/  / /   __   _ .--.   .---. | |             
+                .'.' _ [  | [ `.-. | / /'`\]| |             
+              _/ /__/ | | |  | | | | | \__. |_|             
+             |________|[___][___||__]'.___.'(_)             
 
 """
 
@@ -114,9 +111,8 @@ class ZincWizard(object):
             "security_code": "Please input your card's CVV security code",
             "end_message": "\nYou've finished entering your credit card information!"
             },
-        "write_to_zincrc": "Would you like to write the information you just entered to a configuration file (.zincrc) so you can make orders more easily in the future? We'll only include your shipping address and a hashed credit card token, so no confidential information will be written to your hard drive. [y]/n"
+        "write_to_zincrc": "Would you like to write the information you just entered to a configuration file (~/.zincrc) so you can make orders more easily in the future? We'll only include your shipping address and a hashed credit card token, so no confidential information will be written to your hard drive. [y]/n"
         }
-    MAX_IHMAGE_WIDTH = 50
 
     def __init__(self,
             retailer = "amazon",
@@ -136,7 +132,7 @@ class ZincWizard(object):
         self.shipping_address = None
 
     def get_stored_data(self, filename):
-        default_filename = os.path.join(os.path.dirname(os.path.abspath(__file__)), "../.zincrc")
+        default_filename = os.path.join(os.path.expanduser("~"), ".zincrc")
         if filename != None and os.path.isfile(filename):
             with open(filename, 'rb') as f:
                 return json.loads(f.read())
@@ -223,9 +219,7 @@ class ZincWizard(object):
         asin = self.get_asin(self.product_url)
         product_info = None
         if asin != None:
-            term_width = InterfaceHelpers.get_terminal_size()[0]
-            size = min(term_width/3,self.MAX_IHMAGE_WIDTH)
-            call(["curl", "http://ihmage.com/" + asin + "?size="+str(size)])
+            InterfaceHelpers.print_ihmage_image(asin)
             print "\nLoading product information...\n"
             product_info = AmazonDataFinder.get_amazon_data(asin)
         variants_response = async_response.get_response()
@@ -324,7 +318,7 @@ class ZincWizard(object):
         self.print_indent("Total:            %s" % format_price(components["total"]))
 
     def write_to_zincrc(self):
-        filename = os.path.join(os.path.dirname(os.path.abspath(__file__)), "../.zincrc")
+        filename = os.path.join(os.path.expanduser("~"), ".zincrc")
         if not os.path.isfile(filename) and self.prompt_boolean(self.PROMPTS["write_to_zincrc"]):
             data = {
                 "shipping_address": self.shipping_address,
@@ -401,7 +395,10 @@ class ZincWizard(object):
         collector = []
         for i in xrange(len(response["results"])):
             current = response["results"][i]
-            descriptions.append(str(i) + ") " + current["title"])
+            new_description = str(i) + ") " + current["title"]
+            if "price" in current:
+                new_description += ", " + format_price(current["price"])
+            descriptions.append(new_description)
             asin = self.get_asin(current["product_url"])
             collector.append(current["product_url"])
 
@@ -497,6 +494,8 @@ class AmazonDataFinder(object):
             return False
 
 class InterfaceHelpers(object):
+    MAX_IHMAGE_WIDTH = 50
+
     @classmethod
     def get_terminal_size(klass):
         import os
@@ -522,5 +521,11 @@ class InterfaceHelpers(object):
             cr = (env.get('LINES', 25), env.get('COLUMNS', 80))
         return int(cr[1]), int(cr[0])
 
+    @classmethod
+    def print_ihmage_image(klass, asin):
+        term_width = InterfaceHelpers.get_terminal_size()[0]
+        size = min(term_width/3, InterfaceHelpers.MAX_IHMAGE_WIDTH)
+        call(["curl", "http://ihmage.com/" + asin + "?size="+str(size)])
+
 if __name__ == '__main__':
     ZincWizard().start()
